@@ -8,28 +8,27 @@
 
 #include <pulse/pulseaudio.h>
 
-#include "context.h"
+#include <PulseAudioQt/Context>
+#include <PulseAudioQt/Sink>
+#include <PulseAudioQt/SinkInput>
+#include <PulseAudioQt/Source>
+#include <PulseAudioQt/SourceOutput>
+#include <PulseAudioQt/VolumeObject>
+
 #include "debug.h"
-#include "sink.h"
-#include "sinkinput.h"
-#include "source.h"
-#include "sourceoutput.h"
-#include "volumeobject.h"
 
 #include <QtGlobal>
 
-using namespace QPulseAudio;
+using namespace PulseAudioQt;
 
 VolumeMonitor::VolumeMonitor(QObject *parent)
     : QObject(parent)
 {
-    Context::instance()->ref();
 }
 
 VolumeMonitor::~VolumeMonitor()
 {
     setTarget(nullptr);
-    Context::instance()->unref();
 }
 
 bool VolumeMonitor::isAvailable() const
@@ -48,12 +47,12 @@ void VolumeMonitor::updateVolume(qreal volume)
     Q_EMIT volumeChanged();
 }
 
-QPulseAudio::VolumeObject *QPulseAudio::VolumeMonitor::target() const
+PulseAudioQt::VolumeObject *PulseAudioQt::VolumeMonitor::target() const
 {
     return m_target;
 }
 
-void QPulseAudio::VolumeMonitor::setTarget(QPulseAudio::VolumeObject *target)
+void PulseAudioQt::VolumeMonitor::setTarget(PulseAudioQt::VolumeObject *target)
 {
     if (target == m_target) {
         return;
@@ -98,9 +97,12 @@ void VolumeMonitor::createStream()
     uint32_t streamIdx = PA_INVALID_INDEX;
 
     if (auto *sinkInput = qobject_cast<SinkInput *>(m_target)) {
-        Sink *sink = Context::instance()->sinks().data().value(sinkInput->deviceIndex());
-        if (sink) {
-            sourceIdx = sink->monitorIndex();
+        const auto sinks = Context::instance()->sinks();
+        for (const auto &sink : sinks) {
+            if (sink->index() == sinkInput->deviceIndex()) {
+                sourceIdx = sink->monitorIndex();
+                break;
+            }
         }
         streamIdx = sinkInput->index();
     } else if (auto *sourceOutput = qobject_cast<SourceOutput *>(m_target)) {
